@@ -70,6 +70,7 @@ class BondKeyFigureName(Enum):
     HorizonReturnInterest6M = "interest6m"
     HorizonReturnInterest6M50 = "interest6m50"
     HorizonReturnInterest6Mm50 = "interest6m-50"
+    IndexValue = "index value"
     MacauleyDuration_Deterministic = "macauley_duration"
     MaxOutstandingAmount = "max_outstanding_amount"
     ModifiedDuration_Deterministic = "modduration"
@@ -107,7 +108,7 @@ class BondKeyFigureName(Enum):
     Quote = "quote"
     QuotedSize = "quotedsize"
     Spread = "spread"
-    SpreadRisk = "spread_risk"
+    SpreadRisk = "spreadrisk"
     SwapSpread = "swap_spread"
     Theta = "theta"
     Vega = "vega"
@@ -188,6 +189,7 @@ class TimeSeriesKeyFigureName(Enum):
     HorizonReturnInterest6M = "interest6m"
     HorizonReturnInterest6M50 = "interest6m50"
     HorizonReturnInterest6Mm50 = "interest6m-50"
+    IndexValue = "index value"
     MacauleyDuration_Deterministic = "macauley_duration"
     MaxOutstandingAmount = "max_outstanding_amount"
     ModifiedDuration_Deterministic = "modduration"
@@ -225,7 +227,7 @@ class TimeSeriesKeyFigureName(Enum):
     Quote = "quote"
     QuotedSize = "quotedsize"
     Spread = "spread"
-    SpreadRisk = "spread_risk"
+    SpreadRisk = "spreadrisk"
     SwapSpread = "swap_spread"
     Theta = "theta"
     Vega = "vega"
